import request from '@/utils/request'


//查询查堵总数
export function totalCount(query) {
    return request({
        url: '/blocked/dashboard/totalCount',
        method: 'get',
        params: query
    })
}

// 查询查堵总数柱状图
export function brigadeChart(query) {
    return request({
        url: '/blocked/dashboard/brigadeChart',
        method: 'get',
        params: query
    })
}

//查询总查堵万分率
export function totalRate(query) {
    return request({
        url: '/blocked/dashboard/totalRate',
        method: 'get',
        params: query
    })
}
//查询查堵万分率条形图
export function brigadeRateChart(query) {
    return request({
        url: '/blocked/dashboard/brigadeRateChart',
        method: 'get',
        params: query
    })
}
//每日查堵数量(总表)
export function dailyTrend(query) {
    return request({
        url: '/blocked/dashboard/dailyTrend',
        method: 'get',
        params: query
    })
}
//每日查堵数量(大队对比)
export function dailyBrigadeComparison(query) {
    return request({
        url: '/blocked/dashboard/dailyBrigadeComparison',
        method: 'get',
        params: query
    })
}
//每日查堵万分率(总表)
export function dailyRateTrend(query) {
    return request({
        url: '/blocked/dashboard/dailyRateTrend',
        method: 'get',
        params: query
    })
}
//每日查堵万分率(大队对比)
export function dailyBrigadeRateComparison(query) {
    return request({
        url: '/blocked/dashboard/dailyBrigadeRateComparison',
        method: 'get',
        params: query
    })
}
//每日过检图像数(行检+旅检总表)
export function dailyLuggageTrend(query) {
    return request({
        url: '/blocked/dashboard/dailyLuggageTrend',
        method: 'get',
        params: query
    })
}

//每日过检图像数(行检+旅检 大队对比)
export function dailyBrigadeLuggageComparison(query) {
    return request({
        url: '/blocked/dashboard/dailyBrigadeLuggageComparison',
        method: 'get',
        params: query
    })
}
//查堵物品分布
export function itemDistribution(query) {
    return request({
        url: '/blocked/dashboard/itemDistribution',
        method: 'get',
        params: query
    })
}
//区域查堵数量分布
export function areaDistribution(query) {
    return request({
        url: '/blocked/dashboard/areaDistribution',
        method: 'get',
        params: query
    })
}
//查堵类型分布
export function discriminationDistribution(query) {
    return request({
        url: '/blocked/dashboard/discriminationDistribution',
        method: 'get',
        params: query
    })
}
//查堵时间段过检行李数及万分率
export function timePeriodStats(query) {
    return request({
        url: '/blocked/dashboard/timePeriodStats',
        method: 'get',
        params: query
    })
}
//每日过检行李数及万分率
export function dailyLuggageAndRate(query) {
    return request({
        url: '/blocked/dashboard/dailyLuggageAndRate',
        method: 'get',
        params: query
    })
}
//查堵-AI复查图像总数
export function aiImageStats(query) {
    return request({
        url: '/blocked/dashboard/aiImageStats',
        method: 'get',
        params: query
    })
}
//查堵-AI漏判图像总数
export function aiMissImageStats(query) {
    return request({
        url: '/blocked/dashboard/aiMissImageStats',
        method: 'get',
        params: query
    })
}
//查堵-AI误判图像总数
export function aiErrorImageStats(query) {
    return request({
        url: '/blocked/dashboard/aiErrorImageStats',
        method: 'get',
        params: query
    })
}
//查堵-主管排行榜
export function supervisorRanking(query) {
    return request({
        url: '/blocked/dashboard/supervisorRanking',
        method: 'get',
        params: query
    })
}
//查堵-班组排行榜
export function teamLeaderRanking(query) {
    return request({
        url: '/blocked/dashboard/teamLeaderRanking',
        method: 'get',
        params: query
    })
}
//查堵-人员排行榜
export function reviewedUserRanking(query) {
    return request({
        url: '/blocked/dashboard/reviewedUserRanking',
        method: 'get',
        params: query
    })
}
//查堵-物品位置分布
export function itemLocationDistribution(query) {
    return request({
        url: '/blocked/dashboard/itemLocationDistribution',
        method: 'get',
        params: query
    })
}
//查堵-原因分类分布
export function missCheckReasonDistribution(query) {
    return request({
        url: '/blocked/dashboard/missCheckReasonDistribution',
        method: 'get',
        params: query
    })
}
//查堵-图像难易程度分布
export function difficultyDistribution(query) {
    return request({
        url: '/blocked/dashboard/difficultyDistribution',
        method: 'get',
        params: query
    })
}
//查堵-开机人员持证比例
export function certificateDistribution(query) {
    return request({
        url: '/blocked/dashboard/certificateDistribution',
        method: 'get',
        params: query
    })
}
//查询开机人员年限分布列表全量
export function tenureListAll(query) {
    return request({
        url: '/blocked/tenure/listAll',
        method: 'get',
        params: query
    })
}
//大队开机人员证书分布
export function brigadeCertificateDistribution(query) {
    return request({
        url: '/blocked/dashboard/brigadeCertificateDistribution',
        method: 'get',
        params: query
    })
}
//T1速率统计数据
export function t1RateStats(query) {
    return request({
        url: '/blocked/rate/screen/t1',
        method: 'get',
        params: query
    })
}
//T2速率统计数据
export function t2RateStats(query) {
    return request({
        url: '/blocked/rate/screen/t2',
        method: 'get',
        params: query
    })
}
//国内速率统计数据
export function insideRateStats(query) {
    return request({
        url: '/blocked/rate/screen/domestic',
        method: 'get',
        params: query
    })
}
//国际速率统计数据
export function outsideRateStats(query) {
    return request({
        url: '/blocked/rate/screen/international',
        method: 'get',
        params: query
    })
}
//月考成绩统计
export function monthlyAssessment(query) {
    return request({
        url: '/blocked/missReview/screen/monthlyAssessment',
        method: 'get',
        params: query
    })
}
//本月自测有无漏检统计
export function selfTestHasMissCheck(query) {
    return request({
        url: '/blocked/missReview/screen/selfTestHasMissCheck',
        method: 'get',
        params: query
    })
}
//查询两楼每日查堵走势
export function dailyTerminalTrend(query) {
    return request({
        url: '/blocked/dashboard/brigade/dailyTerminalTrend',
        method: 'get',
        params: query
    })
}
//查询两楼每日过检图像数
export function dailyTerminalLuggageTrend(query) {
    return request({
        url: '/blocked/dashboard/brigade/dailyTerminalLuggageTrend',
        method: 'get',
        params: query
    })
}
//查询两楼查堵数（包含行检）
export function terminalBlockedStats(query) {
    return request({
        url: '/blocked/dashboard/brigade/terminalBlockedStats',
        method: 'get',
        params: query
    })
}
//查询查堵时间段过检行李数
export function timePeriodLuggageStats(query) {
    return request({
        url: '/blocked/dashboard/brigade/timePeriodLuggageStats',
        method: 'get',
        params: query
    })
}
//查询两楼每日查堵万分率
export function dailyTerminalRateTrend(query) {
    return request({
        url: '/blocked/dashboard/brigade/dailyTerminalRateTrend',
        method: 'get',
        params: query
    })
}
//查询查堵物品分布
export function brigadeItemDistribution(query) {
    return request({
        url: '/blocked/dashboard/brigade/itemDistribution',
        method: 'get',
        params: query
    })
}
//查堵-主管排行榜
export function brigadeSupervisorRanking(query) {
    return request({
        url: '/blocked/dashboard/brigade/supervisorRanking',
        method: 'get',
        params: query
    })
}
//查堵-班组排行榜
export function brigadeTeamLeaderRanking(query) {
    return request({
        url: '/blocked/dashboard/brigade/teamLeaderRanking',
        method: 'get',
        params: query
    })
}
//查堵-人员排行榜
export function brigadeReviewedUserRanking(query) {
    return request({
        url: '/blocked/dashboard/brigade/reviewedUserRanking',
        method: 'get',
        params: query
    })
}
//查询查堵男女比例
export function brigadeGenderDistribution(query) {
    return request({
        url: '/blocked/dashboard/brigade/genderDistribution',
        method: 'get',
        params: query
    })
}
//查询查堵人员证书级别分布
export function brigadeCertificateDistributionDetail(query) {
    return request({
        url: '/blocked/dashboard/brigade/certificateLevelDistribution',
        method: 'get',
        params: query
    })
}
//查询证书级别人员基数
export function personnelCertificateBase(query) {
    return request({
        url: '/blocked/dashboard/brigade/personnelCertificateBase',
        method: 'get',
        params: query
    })
}
//查询查堵物品位置分布
export function brigadeItemLocationDistribution(query) {
    return request({
        url: '/blocked/dashboard/brigade/itemLocationDistribution',
        method: 'get',
        params: query
    })
}
//查询查堵-简单/困难图像数
export function brigadeDifficultyDistribution(query) {
    return request({
        url: '/blocked/dashboard/brigade/difficultyDistribution',
        method: 'get',
        params: query
    })
}
//查询查堵-主管分管次数分布
export function brigadeSupervisorDistribution(query) {
    return request({
        url: '/blocked/dashboard/brigade/supervisorDistribution',
        method: 'get',
        params: query
    })
}
//查询查堵原因分类分布
export function brigadeMissCheckReasonDistribution(query) {
    return request({
        url: '/blocked/dashboard/brigade/missCheckReasonDistribution',
        method: 'get',
        params: query
    })
}
//查询查堵人员开机年限分布
export function brigadeOperatingYearsDistribution(query) {
    return request({
        url: '/blocked/dashboard/brigade/operatingYearsDistribution',
        method: 'get',
        params: query
    })
}